<?php
/**
 * @package Catch Themes
 * @subpackage Simple Catch
 * @since Simple Catch 3.0
 */


if( ! function_exists( 'simplecatch_is_favicon_active' ) ) :
	/**
	* Return true if no core site icon is present
	*
	* @since Simple Catch 3.0
	*/
	function simplecatch_is_site_icon_active( $control ) {
		//Check if has_site_icon function exists. If it does not, WP version is less than 4.3
		if ( function_exists( 'has_site_icon' ) ) {
			//Return true if core site icon is not present, else return false
			return !has_site_icon();
		}
		else {
			return true;
		}
	}
endif;


if( ! function_exists( 'simplecatch_is_feed_url_present' ) ) :
	/**
	* Return true if feed url is present
	*
	* @since Simple Catch 3.0
	*/
	function simplecatch_is_feed_url_present( $control ) {
		global $simplecatch_options_settings;

    	$options = $simplecatch_options_settings;

		return ( isset( $options['feed_url'] ) && '' != $options['feed_url'] );
	}
endif;


if( ! function_exists( 'simplecatch_is_header_code_present' ) ) :
	/**
	* Return true if header code is present
	*
	* @since Simple Catch 3.0
	*/
	function simplecatch_is_header_code_present( $control ) {
		global $simplecatch_options_settings;

    	$options = $simplecatch_options_settings;

		return ( isset( $options['analytic_header'] ) && '' != $options['analytic_header'] );
	}
endif;


if( ! function_exists( 'simplecatch_is_footer_code_present' ) ) :
	/**
	* Return true if footer code is present
	*
	* @since Simple Catch 3.0
	*/
	function simplecatch_is_footer_code_present( $control ) {
		global $simplecatch_options_settings;

    	$options = $simplecatch_options_settings;

		return ( isset( $options['analytic_footer'] ) && '' != $options['analytic_footer'] );
	}
endif;

if( ! function_exists( 'simplecatch_is_slider_active' ) ) :
	/**
	* Return true if slider is active
	*
	* @since  Simple Catch Pro 3.4
	*/
	function simplecatch_is_slider_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'simplecatch_options[enable_slider]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected
		return ( $enable == 'enable-slider-allpage' || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && $enable == 'enable-slider-homepage' ) );
	}
endif;


if( ! function_exists( 'simplecatch_is_post_slider_active' ) ) :
	/**
	* Return true if post slider is active
	*
	* @since  Simple Catch Pro 3.4
	*/
	function simplecatch_is_post_slider_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'simplecatch_options[enable_slider]' )->value();

		$type 	= $control->manager->get_setting( 'simplecatch_options[select_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected
		return ( ( $enable == 'enable-slider-allpage' || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && $enable == 'enable-slider-homepage' ) ) && 'post-slider' == $type );
	}
endif;

if( ! function_exists( 'simplecatch_is_page_slider_active' ) ) :
	/**
	* Return true if page slider is active
	*
	* @since  Simple Catch Pro 3.4
	*/
	function simplecatch_is_page_slider_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'simplecatch_options[enable_slider]' )->value();

		$type 	= $control->manager->get_setting( 'simplecatch_options[select_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected
		return ( ( $enable == 'enable-slider-allpage' || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && $enable == 'enable-slider-homepage' ) ) && 'page-slider' == $type );
	}
endif;



if( ! function_exists( 'simplecatch_is_category_slider_active' ) ) :
	/**
	* Return true if category slider is active
	*
	* @since  Simple Catch Pro 3.4
	*/
	function simplecatch_is_category_slider_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'simplecatch_options[enable_slider]' )->value();

		$type 	= $control->manager->get_setting( 'simplecatch_options[select_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected
		return ( ( $enable == 'enable-slider-allpage' || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && $enable == 'enable-slider-homepage' ) ) && 'category-slider' == $type );
	}
endif;

if( ! function_exists( 'simplecatch_is_image_slider_active' ) ) :
	/**
	* Return true if image slider is active
	*
	* @since  Simple Catch Pro 3.4
	*/
	function simplecatch_is_image_slider_active( $control ) {
		global $wp_query;

		$page_id = $wp_query->get_queried_object_id();

		// Front page display in Reading Settings
		$page_for_posts = get_option('page_for_posts');

		$enable = $control->manager->get_setting( 'simplecatch_options[enable_slider]' )->value();

		$type 	= $control->manager->get_setting( 'simplecatch_options[select_slider_type]' )->value();

		//return true only if previwed page on customizer matches the type of slider option selected
		return ( ( $enable == 'enable-slider-allpage' || ( ( is_front_page() || ( is_home() && $page_for_posts != $page_id ) ) && $enable == 'enable-slider-homepage' ) ) && 'image-slider' == $type );
	}
endif;

if( ! function_exists( 'simplecatch_is_woocommerce_active' ) ) :
	/**
	* Return true if woocommerce is active
	*
	* @since  Simple Catch Pro 3.5
	*/
	function simplecatch_is_woocommerce_active( $control ) {
		//return true only if woocommerce is active
		return ( class_exists( 'woocommerce' ) );
	}
endif;
