<?php
/**
 * Simple Catch Customizer/Theme Options
 *
 * @package Catch Themes
 * @subpackage Simple Catch
 * @since Simple Catch 3.0
 */

/**
 * Implements Simple Catch theme options into Theme Customizer.
 *
 * @param $wp_customize Theme Customizer object
 * @return void
 *
 * @since Simple Catch 3.0
 */
function simplecatch_customize_register( $wp_customize ) {
	global $simplecatch_options_settings, $simplecatch_options_defaults;

    $options = $simplecatch_options_settings;

	$defaults = $simplecatch_options_defaults;

	//Custom Controls
	require get_template_directory() . '/functions/panel/customizer/customizer-custom-controls.php';

	$theme_slug = 'simplecatch_';

	$settings_page_tabs = array(
		'theme_options' => array(
			'id' 			=> 'theme_options',
			'title' 		=> __( 'Theme Options', 'simple-catch' ),
			'description' 	=> __( 'Basic theme Options', 'simple-catch' ),
			'sections' 		=> array(
				'responsive_design' => array(
					'id' 			=> 'responsive_design',
					'title' 		=> __( 'Responsive Design', 'simple-catch' ),
					'description' 	=> '',
				),
				'favicon' => array(
					'id' 			=> 'favicon',
					'title' 		=> __( 'Favicon', 'simple-catch' ),
					'description' 	=> '',
				),
				'web_clip_icon_options' => array(
					'id' 			=> 'web_clip_icon_options',
					'title' 		=> __( 'Webclip Icon Options', 'simple-catch' ),
					'description' 	=> __( 'Web Clip Icon for Apple devices. Recommended Size - Width 144px and Height 144px height, which will support High Resolution Devices like iPad Retina', 'simple-catch' )
				),
				'header_right_sidebar_options' => array(
					'id' 			=> 'header_right_sidebar_options',
					'title' 		=> __( 'Header Right Sidebar Options', 'simple-catch' ),
					'description' 	=> '',
				),
				'typography' => array(
					'id' 			=> 'typography',
					'title' 		=> __( 'Font Family Options', 'simple-catch' ),
					'description' 	=> '',
				),
				'typography_size' => array(
					'id' 			=> 'typography_size',
					'title' 		=> __( 'Font Size Options', 'simple-catch' ),
					'description' 	=> '',
				),
				'default_layout' => array(
					'id' 			=> 'default_layout',
					'title' 		=> __( 'Default Layout', 'simple-catch' ),
					'description' 	=> '',
				),
				'homepage_frontpage_settings' => array(
					'id' 			=> 'homepage_frontpage_settings',
					'title' 		=> __( 'Homepage / Frontpage Category Setting', 'simple-catch' ),
					'description' 	=> '',
				),
				'search_text_settings' => array(
					'id' 			=> 'search_text_settings',
					'title' 		=> __( 'Search Text Settings', 'simple-catch' ),
					'description' 	=> '',
				),
				'excerpt_more_tag_settings' => array(
					'id' 			=> 'excerpt_more_tag_settings',
					'title' 		=> __( 'Excerpt / More Tag Settings', 'simple-catch' ),
					'description' 	=> '',
				),
				'feed_redirect' => array(
					'id' 			=> 'feed_redirect',
					'title' 		=> __( 'Feed Redirect', 'simple-catch' ),
					'description' 	=> '',
				),
				'custom_css' => array(
					'id' 			=> 'custom_css',
					'title' 		=> __( 'Custom CSS', 'simple-catch' ),
					'description' 	=> '',
				),
				'footer_options' => array(
					'id' 			=> 'footer_options',
					'title' 		=> __( 'Footer Options', 'simple-catch' ),
					'description' 	=> '',
				),
				'scrollup_options' => array(
					'id' 			=> 'scrollup_options',
					'title' 		=> __( 'Scroll Up', 'simple-catch' ),
					'description' 	=> '',
				),
				'update_notifier' => array(
					'id' 			=> 'update_notifier',
					'title' 		=> __( 'Update Notifier', 'simple-catch' ),
					'description' 	=> '',
				),

			),
		),

		'featured_post_slider' => array(
			'id' 			=> 'featured_post_slider',
			'title' 		=> __( 'Featured Slider', 'simple-catch' ),
			'description' 	=> __( 'Featured Slider', 'simple-catch' ),
			'sections' 		=> array(
				'add_slider_options' => array(
					'id' 			=> 'add_slider_options',
					'title' 		=> __( 'Slider Options', 'simple-catch' ),
					'description' 	=> '',
				),
				'slider_effect_options' => array(
					'id' 			=> 'slider_effect_options',
					'title' 		=> __( 'Slider Effect Options', 'simple-catch' ),
					'description' 	=> '',
				),
			)
		),
		'webmaster_tools' => array(
			'id' 			=> 'webmaster_tools',
			'title' 		=> __( 'Webmaster Tools', 'simple-catch' ),
			'description' 	=> '',
			'sections' 		=> array(
				'site_verification' => array(
					'id' 			=> 'site_verification',
					'title' 		=> __( 'Site Verification', 'simple-catch' ),
					'description' 	=> '',
				),
				'header_footer_codes' => array(
					'id' 			=> 'header_footer_codes',
					'title' 		=> __( 'Header and Footer Codes', 'simple-catch' ),
					'description' 	=> '',
				),
			)
		),

	);

	$wp_customize->get_control( 'background_color' )->priority = '40';
	$wp_customize->get_control( 'background_color' )->label = __( 'Content Background Color', 'simple-catch' );

	//Add Panels and sections
	foreach ( $settings_page_tabs as $panel ) {
		$panel_priority = 200;
		if( 'webmaster_tools' == $panel['id'] ){
			$panel_priority = 202;
		}
		$wp_customize->add_panel(
			$theme_slug . $panel['id'],
			array(
				'priority' 		=> $panel_priority,
				'capability' 	=> 'edit_theme_options',
				'title' 		=> $panel['title'],
				'description' 	=> $panel['description'],
			)
		);

		// Loop through tabs for sections
		foreach ( $panel['sections'] as $section ) {
			$params = array(
								'title'			=> $section['title'],
								'description'	=> $section['description'],
								'panel'			=> $theme_slug . $panel['id']
							);

			if ( isset( $section['active_callback'] ) ) {
				$params['active_callback'] = $section['active_callback'];
			}

			$wp_customize->add_section(
				// $id
				$theme_slug . $section['id'],
				// parameters
				$params

			);
		}
	}

	$wp_customize->add_section(
		// $id
		$theme_slug . 'social_links',
		// parameters
		array(
			'priority'	=> 201,
			'title' => __( 'Social Links', 'simple-catch' ),
		)

	);

	$settings_parameters = array(
		//Responsive Design
		'disable_responsive' => array(
			'id' 				=> 'disable_responsive',
			'title' 			=> __( 'Check to Disable Responsive Design', 'simple-catch' ),
			'description'		=> '',
			'field_type' 		=> 'checkbox',
			'sanitize' 			=> 'simplecatch_sanitize_checkbox',
			'panel'				=> 'theme_options',
			'section' 			=> 'responsive_design',
			'default' 			=> $defaults['disable_responsive'],
		),
		//Header Logo Options
		'featured_logo_header' => array(
			'id' 				=> 'featured_logo_header',
			'title' 			=> __( 'Header Logo', 'simple-catch' ),
			'description'		=> '',
			'field_type' 		=> 'image',
			'sanitize' 			=> 'simplecatch_sanitize_image',
			'section' 			=> 'title_tagline',
			'default' 			=> $defaults['featured_logo_header'],
			'priority'			=> '50',
		),
		'remove_header_logo' => array(
			'id' 				=> 'remove_header_logo',
			'title' 			=> __( 'Check to Disable Site Title', 'simple-catch' ),
			'description'		=> '',
			'field_type' 		=> 'checkbox',
			'sanitize' 			=> 'simplecatch_sanitize_checkbox',
			'section' 			=> 'title_tagline',
			'default' 			=> $defaults['remove_header_logo'],
			'priority'			=> '60',
		),
		'remove_site_title' => array(
			'id' 				=> 'remove_site_title',
			'title' 			=> __( 'Check to Disable Header Logo', 'simple-catch' ),
			'description'		=> '',
			'field_type' 		=> 'checkbox',
			'sanitize' 			=> 'simplecatch_sanitize_checkbox',
			'section' 			=> 'title_tagline',
			'default' 			=> $defaults['remove_site_title'],
			'priority'			=> '70',
		),
		'remove_site_description' => array(
			'id' 				=> 'remove_site_description',
			'title' 			=> __( 'Check to Disable Site Description', 'simple-catch' ),
			'description'		=> '',
			'field_type' 		=> 'checkbox',
			'sanitize' 			=> 'simplecatch_sanitize_checkbox',
			'section' 			=> 'title_tagline',
			'default' 			=> $defaults['remove_site_description'],
			'priority'			=> '80',
		),
		'site_title_above' => array(
			'id' 				=> 'site_title_above',
			'title' 			=> __( 'Check to Move Site Title and Description Before Header/Logo Image', 'simple-catch' ),
			'description'		=> '',
			'field_type' 		=> 'checkbox',
			'sanitize' 			=> 'simplecatch_sanitize_checkbox',
			'section' 			=> 'title_tagline',
			'default' 			=> $defaults['site_title_above'],
			'priority'			=> '90',
		),

		//Header Right Sidebar Options
		'disable_header_right_sidebar' => array(
			'id' 				=> 'disable_header_right_sidebar',
			'title' 			=> __( 'Check to Disable Header Right Sidebar', 'simple-catch' ),
			'description'		=> '',
			'field_type' 		=> 'checkbox',
			'sanitize' 			=> 'simplecatch_sanitize_checkbox',
			'section' 			=> 'header_right_sidebar_options',
			'default' 			=> $defaults['disable_header_right_sidebar'],
		),

		//Color Scheme
		'color_scheme' => array(
			'id' 			=> 'color_scheme',
			'title' 		=> __( 'Default Color Scheme', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'radio',
			'sanitize' 		=> 'simplecatch_sanitize_select',
			'section' 		=> 'colors',
			'default' 		=> $defaults['color_scheme'],
			'choices'		=> simplecatch_color_schemes(),
			'priority'		=> '10',
		),
		'header_top_background' => array(
			'id' 			=> 'header_top_background',
			'title' 		=> __( 'Header Top Background Color', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'section' 		=> 'colors',
			'default' 		=> $defaults['header_top_background'],
			'priority'		=> '20',
		),
		'header_background' => array(
			'id' 			=> 'header_background',
			'title' 		=> __( 'Header Background Color', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'section' 		=> 'colors',
			'default' 		=> $defaults['header_background'],
			'priority'		=> '30',
		),
		'footer_background' => array(
			'id' 			=> 'footer_background',
			'title' 		=> __( 'Footer Background Color', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'section' 		=> 'colors',
			'default' 		=> $defaults['footer_background'],
			'priority'		=> '50',
		),
		'footer_sidebar_background' => array(
			'id' 			=> 'footer_sidebar_background',
			'title' 		=> __( 'Footer Sidebar Background Color', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'section' 		=> 'colors',
			'default' 		=> $defaults['footer_sidebar_background'],
			'priority'		=> '60',
		),
		'header_footer_border' => array(
			'id' 			=> 'header_footer_border',
			'title' 		=> __( 'Header & Footer Border Color', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'section' 		=> 'colors',
			'default' 		=> $defaults['header_footer_border'],
			'priority'		=> '70',
		),
		'title_color' => array(
			'id' 			=> 'title_color',
			'title' 		=> __( 'Site Title Color', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'section' 		=> 'colors',
			'default' 		=> $defaults['title_color'],
			'priority'		=> '80',
		),
		'tagline_color' => array(
			'id' 			=> 'tagline_color',
			'title' 		=> __( 'Site Tagline/ Description Color', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'section' 		=> 'colors',
			'default' 		=> $defaults['tagline_color'],
			'priority'		=> '90',
		),
		'heading_color' => array(
			'id' 			=> 'heading_color',
			'title' 		=> __( 'Heading Color', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'section' 		=> 'colors',
			'default' 		=> $defaults['heading_color'],
			'priority'		=> '100',
		),
		'meta_color' => array(
			'id' 			=> 'meta_color',
			'title' 		=> __( 'Meta Description Color', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'section' 		=> 'colors',
			'default' 		=> $defaults['meta_color'],
			'priority'		=> '110',
		),
		'text_color' => array(
			'id' 			=> 'text_color',
			'title' 		=> __( 'Text Color', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'section' 		=> 'colors',
			'default' 		=> $defaults['text_color'],
			'priority'		=> '120',
		),
		'link_color' => array(
			'id' 			=> 'link_color',
			'title' 		=> __( 'Link Color', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'section' 		=> 'colors',
			'default' 		=> $defaults['link_color'],
			'priority'		=> '130',
		),
		'widget_heading_color' => array(
			'id' 			=> 'widget_heading_color',
			'title' 		=> __( 'Sidebar Widget Heading Color', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'section' 		=> 'colors',
			'default' 		=> $defaults['widget_heading_color'],
			'priority'		=> '140',
		),
		'widget_text_color' => array(
			'id' 			=> 'widget_text_color',
			'title' 		=> __( 'Sidebar Widget Text Color', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'section' 		=> 'colors',
			'default' 		=> $defaults['widget_text_color'],
			'priority'		=> '150',
		),
		'widget_link_color' => array(
			'id' 			=> 'widget_link_color',
			'title' 		=> __( 'Sidebar Widget Link Color', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'section' 		=> 'colors',
			'default' 		=> $defaults['widget_link_color'],
			'priority'		=> '160',
		),
		'menu_bg_color' => array(
			'id' 			=> 'menu_bg_color',
			'title' 		=> __( 'Menu Background Color', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'section' 		=> 'colors',
			'default' 		=> $defaults['menu_bg_color'],
			'priority'		=> '170',
		),
		'menu_text_color' => array(
			'id' 			=> 'menu_text_color',
			'title' 		=> __( 'Menu Text Color', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'section' 		=> 'colors',
			'default' 		=> $defaults['menu_text_color'],
			'priority'		=> '180',
		),
		'border_color' => array(
			'id' 			=> 'border_color',
			'title' 		=> __( 'Menu Border Color', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'section' 		=> 'colors',
			'default' 		=> $defaults['border_color'],
			'priority'		=> '190',
		),
		'hover_active_color' => array(
			'id' 			=> 'widget_link_color',
			'title' 		=> __( 'Menu Hover & Active Background Color', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'section' 		=> 'colors',
			'default' 		=> $defaults['widget_text_color'],
			'priority'		=> '200',
		),
		'hover_active_text_color' => array(
			'id' 			=> 'hover_active_text_color',
			'title' 		=> __( 'Menu Hover & Active Text Color', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'section' 		=> 'colors',
			'default' 		=> $defaults['hover_active_text_color'],
			'priority'		=> '210',
		),
		'sub_menu_bg_color' => array(
			'id' 			=> 'sub_menu_bg_color',
			'title' 		=> __( 'Sub-Menu Background Color', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'section' 		=> 'colors',
			'default' 		=> $defaults['sub_menu_bg_color'],
			'priority'		=> '220',
		),
		'sub_menu_text_color' => array(
			'id' 			=> 'sub_menu_text_color',
			'title' 		=> __( 'Sub-Menu Text Color', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'section' 		=> 'colors',
			'default' 		=> $defaults['sub_menu_text_color'],
			'priority'		=> '230',
		),
		'sub_menu_hover_bg_color' => array(
			'id' 			=> 'sub_menu_hover_bg_color',
			'title' 		=> __( 'Sub-Menu Hover Background Color', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'section' 		=> 'colors',
			'default' 		=> $defaults['sub_menu_hover_bg_color'],
			'priority'		=> '240',
		),
		'sub_menu_hover_text_color' => array(
			'id' 			=> 'sub_menu_hover_text_color',
			'title' 		=> __( 'Sub-Menu Hover Text Color', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'section' 		=> 'colors',
			'default' 		=> $defaults['sub_menu_hover_text_color'],
			'priority'		=> '250',
		),
		'scrollup_bg_color' => array(
			'id' 			=> 'scrollup_bg_color',
			'title' 		=> __( 'Scroll Up Background Color', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'section' 		=> 'colors',
			'default' 		=> $defaults['scrollup_bg_color'],
			'priority'		=> '260',
		),
		'scrollup_text_color' => array(
			'id' 			=> 'scrollup_text_color',
			'title' 		=> __( 'Scroll Up Text Color', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'color',
			'sanitize' 		=> 'sanitize_hex_color',
			'section' 		=> 'colors',
			'default' 		=> $defaults['scrollup_text_color'],
			'priority'		=> '270',
		),
		'reset_color' => array(
			'id' 			=> 'reset_color',
			'title' 		=> __( 'Check to Reset Color', 'simple-catch' ),
			'description'	=> __( 'Please refresh the customizer after saving if reset option is used', 'simple-catch' ),
			'transport'		=> 'postMessage',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'simplecatch_sanitize_reset_color',
			'section' 		=> 'colors',
			'default' 		=> $defaults['reset_color'],
			'priority'		=> '280',
		),

		//Font Family Options
		'body_font' => array(
			'id' 			=> 'body_font',
			'title' 		=> __( 'Default Font Family', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'simplecatch_sanitize_select',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography',
			'default' 		=> $defaults['body_font'],
			'choices'		=> simplecatch_available_fonts()
		),
		'title_font' => array(
			'id' 			=> 'title_font',
			'title' 		=> __( 'Site Title Font Family', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'simplecatch_sanitize_select',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography',
			'default' 		=> $defaults['title_font'],
			'choices'		=> simplecatch_available_fonts()
		),
		'tagline_font' => array(
			'id' 			=> 'tagline_font',
			'title' 		=> __( 'Site Tagline Font Family', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'simplecatch_sanitize_select',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography',
			'default' 		=> $defaults['tagline_font'],
			'choices'		=> simplecatch_available_fonts()
		),
		'content_font' => array(
			'id' 			=> 'content_font',
			'title' 		=> __( 'Content Font Family', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'simplecatch_sanitize_select',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography',
			'default' 		=> $defaults['content_font'],
			'choices'		=> simplecatch_available_fonts()
		),
		'headings_font' => array(
			'id' 			=> 'headings_font',
			'title' 		=> __( 'Headings Font Family', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'simplecatch_sanitize_select',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography',
			'default' 		=> $defaults['headings_font'],
			'choices'		=> simplecatch_available_fonts()
		),
		'reset_typography' => array(
			'id' 			=> 'reset_typography',
			'title' 		=> __( 'Check to Reset Fonts', 'simple-catch' ),
			'description'	=> __( 'Please refresh the customizer after saving if reset option is used', 'simple-catch' ),
			'transport'		=> 'postMessage',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'simplecatch_sanitize_reset_typography',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography',
			'default' 		=> $defaults['reset_typography'],
		),

		//Typography Size
		'body_font_size' => array(
			'id' 			=> 'body_font_size',
			'title' 		=> __( 'Default Font Size', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography_size',
			'default' 		=> $defaults['body_font_size']
		),
		'body_line_height' => array(
			'id' 			=> 'body_line_height',
			'title' 		=> __( 'Default Line Height', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography_size',
			'default' 		=> $defaults['body_line_height']
		),
		'site_title_font_size' => array(
			'id' 			=> 'site_title_font_size',
			'title' 		=> __( 'Site Title Font Size', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography_size',
			'default' 		=> $defaults['site_title_font_size']
		),
		'site_title_line_height' => array(
			'id' 			=> 'site_title_line_height',
			'title' 		=> __( 'Site Title Line Height', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography_size',
			'default' 		=> $defaults['site_title_line_height']
		),
		'site_description_font_size' => array(
			'id' 			=> 'site_description_font_size',
			'title' 		=> __( 'Site Tagline Font Size', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography_size',
			'default' 		=> $defaults['site_description_font_size']
		),
		'site_description_line_height' => array(
			'id' 			=> 'site_description_line_height',
			'title' 		=> __( 'Site Tagline Line Height', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography_size',
			'default' 		=> $defaults['site_description_line_height']
		),
		'content_title_font_size' => array(
			'id' 			=> 'content_title_font_size',
			'title' 		=> __( 'Content Title Font Size', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography_size',
			'default' 		=> $defaults['content_title_font_size']
		),
		'content_title_line_height' => array(
			'id' 			=> 'content_title_line_height',
			'title' 		=> __( 'Content Title Line Height', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography_size',
			'default' 		=> $defaults['content_title_line_height']
		),
		'h1_font_size' => array(
			'id' 			=> 'h1_font_size',
			'title' 		=> __( 'H1 Font Size', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography_size',
			'default' 		=> $defaults['h1_font_size']
		),
		'h2_font_size' => array(
			'id' 			=> 'h2_font_size',
			'title' 		=> __( 'H2 Font Size', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography_size',
			'default' 		=> $defaults['h2_font_size']
		),
		'h3_font_size' => array(
			'id' 			=> 'h3_font_size',
			'title' 		=> __( 'H3 Font Size', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography_size',
			'default' 		=> $defaults['h3_font_size']
		),
		'h4_font_size' => array(
			'id' 			=> 'h4_font_size',
			'title' 		=> __( 'H4 Font Size', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography_size',
			'default' 		=> $defaults['h4_font_size']
		),
		'headings_line_height' => array(
			'id' 			=> 'headings_line_height',
			'title' 		=> __( 'Headings Line Height', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography_size',
			'default' 		=> $defaults['headings_line_height']
		),
		'content_font_size' => array(
			'id' 			=> 'content_font_size',
			'title' 		=> __( 'Content Font Size', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography_size',
			'default' 		=> $defaults['content_font_size']
		),
		'content_line_height' => array(
			'id' 			=> 'content_line_height',
			'title' 		=> __( 'Content Line Height', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'multiple-input',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography_size',
			'default' 		=> $defaults['content_line_height']
		),
		'reset_typography_font_size' => array(
			'id' 			=> 'reset_typography_font_size',
			'title' 		=> __( 'Check to Reset Font Size', 'simple-catch' ),
			'description'	=> __( 'Please refresh the customizer after saving if reset option is used', 'simple-catch' ),
			'transport'		=> 'postMessage',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'simplecatch_sanitize_reset_typography_size',
			'panel' 		=> 'theme_options',
			'section' 		=> 'typography_size',
			'default' 		=> $defaults['reset_typography_font_size'],
			'priority'		=> '999',
		),


		//Favicon
		'remove_favicon' => array(
			'id' 				=> 'remove_favicon',
			'title' 			=> __( 'Check to Disable Favicon', 'simple-catch' ),
			'description'		=> '',
			'field_type' 		=> 'checkbox',
			'sanitize' 			=> 'simplecatch_sanitize_checkbox',
			'panel' 			=> 'theme_options',
			'section' 			=> 'favicon',
			'default' 			=> $defaults['remove_favicon'],
			'active_callback'	=> 'simplecatch_is_site_icon_active'
		),
		'fav_icon' => array(
			'id' 				=> 'fav_icon',
			'title' 			=> __( 'Fav Icon', 'simple-catch' ),
			'description'		=> '',
			'field_type' 		=> 'image',
			'sanitize' 			=> 'simplecatch_sanitize_image',
			'panel' 			=> 'theme_options',
			'section' 			=> 'favicon',
			'default' 			=> $defaults['fav_icon'],
			'active_callback'	=> 'simplecatch_is_site_icon_active'
		),

		//Web Clip Icon
		'web_clip' => array(
			'id' 				=> 'web_clip',
			'title' 			=> __( 'Web Clip Icon', 'simple-catch' ),
			'description'		=> '',
			'field_type' 		=> 'image',
			'sanitize' 			=> 'simplecatch_sanitize_image',
			'panel' 			=> 'theme_options',
			'section' 			=> 'web_clip_icon_options',
			'default' 			=> $defaults['web_clip'],
			'active_callback'	=> 'simplecatch_is_site_icon_active'
		),

		//Layout Options
		'sidebar_layout' => array(
			'id' 			=> 'sidebar_layout',
			'title' 		=> __( 'Default Layout', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'simplecatch_sanitize_select',
			'panel' 		=> 'theme_options',
			'section' 		=> 'default_layout',
			'default' 		=> $defaults['sidebar_layout'],
			'choices'		=> simplecatch_sidebar_layout_options(),
		),
		'woocommerce_layout' => array(
			'id'              => 'woocommerce_layout',
			'title'           => __( 'WooCommerce Layout', 'simple-catch' ),
			'description'     => '',
			'field_type'      => 'select',
			'sanitize'        => 'simplecatch_sanitize_select',
			'panel'           => 'theme_options',
			'section'         => 'default_layout',
			'default'         => $defaults['sidebar_layout'],
			'active_callback' => 'simplecatch_is_woocommerce_active',
			'choices'         => simplecatch_sidebar_layout_options(),
		),
		'content_layout' => array(
			'id' 			=> 'content_layout',
			'title' 		=> __( 'Content Layout', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'simplecatch_sanitize_select',
			'panel' 		=> 'theme_options',
			'section' 		=> 'default_layout',
			'default' 		=> $defaults['content_layout'],
			'choices'		=> simplecatch_content_layout_options(),
		),
		'reset_layout' => array(
			'id' 			=> 'reset_layout',
			'title' 		=> __( 'Reset Layout', 'simple-catch' ),
			'description'	=> __( 'Please refresh the customizer after saving if reset option is used', 'simple-catch' ),
			'transport'		=> 'postMessage',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'simplecatch_sanitize_reset_layout',
			'panel' 		=> 'theme_options',
			'section' 		=> 'default_layout',
			'default' 		=> $defaults['reset_layout'],
		),

		//Homepage/Frontpage Settings
		'front_page_category' => array(
			'id' 			=> 'front_page_category',
			'title' 		=> __( 'Front page posts categories:', 'simple-catch' ),
			'description'	=> __( 'Only posts that belong to the categories selected here will be displayed on the front page', 'simple-catch' ),
			'field_type' 	=> 'category-multiple',
			'sanitize' 		=> 'simplecatch_sanitize_category_list',
			'panel' 		=> 'theme_options',
			'section' 		=> 'homepage_frontpage_settings',
			'default' 		=> $defaults['front_page_category']
		),

		//Search Settings
		'search_display_text' => array(
			'id' 			=> 'search_display_text',
			'title' 		=> __( 'Default Display Text in Search', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'text',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'search_text_settings',
			'default' 		=> $defaults['search_display_text']
		),
		'search_button_text' => array(
			'id' 			=> 'search_button_text',
			'title' 		=> __( 'Search Button\'s text', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'text',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'search_text_settings',
			'default' 		=> $defaults['search_button_text']
		),

		//Excerpt More Settings
		'more_tag_text' => array(
			'id' 			=> 'more_tag_text',
			'title' 		=> __( 'More Tag Text', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'text',
			'sanitize' 		=> 'sanitize_text_field',
			'panel' 		=> 'theme_options',
			'section' 		=> 'excerpt_more_tag_settings',
			'default' 		=> $defaults['more_tag_text']
		),
		'excerpt_length' => array(
			'id' 			=> 'excerpt_length',
			'title' 		=> __( 'Excerpt length(words)', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'number',
			'sanitize' 		=> 'simplecatch_sanitize_number_range',
			'panel' 		=> 'theme_options',
			'section' 		=> 'excerpt_more_tag_settings',
			'default' 		=> $defaults['excerpt_length'],
			'input_attrs' 	=> array(
					            'style' => 'width: 45px;',
					            'min'   => 0,
					            'max'   => 999999,
					            'step'  => 1,
					        	)
		),
		'feed_url' => array(
			'id' 				=> 'feed_url',
			'title' 			=> __( 'Feed Redirect URL', 'simple-catch' ),
			'description' 		=> __( ' Add in the Feedburner URL', 'simple-catch' ),
			'field_type' 		=> 'url',
			'sanitize' 			=> 'esc_url_raw',
			'panel' 			=> 'theme_options',
			'section' 			=> 'feed_redirect',
			'default' 			=> $defaults['feed_url'],
		),

		//Custom Css
		'custom_css' => array(
			'id' 			=> 'custom_css',
			'title' 		=> __( 'Enter your custom CSS styles', 'simple-catch' ),
			'description' 	=> '',
			'field_type' 	=> 'textarea',
			'sanitize' 		=> 'simplecatch_sanitize_custom_css',
			'panel' 		=> 'theme_options',
			'section' 		=> 'custom_css',
			'default' 		=> $defaults['custom_css']
		),

		//Slider Options
		'enable_slider' => array(
			'id' 			=> 'enable_slider',
			'title' 		=> __( 'Enable Slider', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'select',
			'sanitize' 		=> 'simplecatch_sanitize_select',
			'panel' 		=> 'featured_post_slider',
			'section' 		=> 'add_slider_options',
			'default' 		=> $defaults['enable_slider'],
			'choices'		=> simplecatch_enable_slider_options(),
		),
		'select_slider_type' => array(
			'id' 				=> 'select_slider_type',
			'title' 			=> __( 'Select Slider Type', 'simple-catch' ),
			'description'		=> '',
			'field_type' 		=> 'select',
			'sanitize' 			=> 'simplecatch_sanitize_select',
			'panel' 			=> 'featured_post_slider',
			'section' 			=> 'add_slider_options',
			'default' 			=> $defaults['select_slider_type'],
			'active_callback'	=> 'simplecatch_is_slider_active',
			'choices'			=> simplecatch_slider_types(),
		),

		//Featured Post Slider
		'exclude_slider_post' => array(
			'id' 				=> 'exclude_slider_post',
			'title' 			=> __( 'Check to Exclude Slider posts from Homepage posts', 'simple-catch' ),
			'description'		=> '',
			'field_type' 		=> 'checkbox',
			'sanitize' 			=> 'simplecatch_sanitize_checkbox',
			'panel' 			=> 'featured_post_slider',
			'section' 			=> 'add_slider_options',
			'default' 			=> $defaults['exclude_slider_post'],
			'active_callback'	=> 'simplecatch_is_post_slider_active'
		),

		//Featured Category Slider
		'slider_category' => array(
			'id' 				=> 'slider_category',
			'title' 			=> __( 'Select Slider Categories', 'simple-catch' ),
			'description'		=> __( 'Use this only is you want to display posts from Specific Categories in Featured Slider', 'simple-catch' ),
			'field_type' 		=> 'category-multiple',
			'sanitize' 			=> 'simplecatch_sanitize_category_list',
			'panel' 			=> 'featured_post_slider',
			'section' 			=> 'add_slider_options',
			'default' 			=> $defaults['slider_category'],
			'active_callback' 	=> 'simplecatch_is_category_slider_active'
		),
		'slider_qty' => array(
			'id' 				=> 'slider_qty',
			'title' 			=> __( 'Number of Slides', 'simple-catch' ),
			'description'		=> __( 'Customizer page needs to be refreshed after saving if number of slides is changed', 'simple-catch' ),
			'field_type' 		=> 'number',
			'sanitize' 			=> 'simplecatch_sanitize_number_range',
			'panel' 			=> 'featured_post_slider',
			'section' 			=> 'add_slider_options',
			'default' 			=> $defaults['slider_qty'],
			'input_attrs' 		=> array(
						            'style' => 'width: 45px;',
						            'min'   => 0,
						            'max'   => 20,
						            'step'  => 1,
						        	)
		),

		'remove_noise_effect' => array(
			'id' 				=> 'remove_noise_effect',
			'title' 			=> __( 'Check to Disable Slider Background Effect', 'simple-catch' ),
			'description'		=> '',
			'field_type' 		=> 'checkbox',
			'sanitize' 			=> 'simplecatch_sanitize_checkbox',
			'panel' 			=> 'featured_post_slider',
			'section' 			=> 'slider_effect_options',
			'default' 			=> $defaults['remove_noise_effect'],
		),
		'transition_effect' => array(
			'id' 				=> 'transition_effect',
			'title' 			=> __( 'Transition Effect', 'simple-catch' ),
			'description'		=> '',
			'field_type' 		=> 'select',
			'sanitize' 			=> 'simplecatch_sanitize_select',
			'panel' 			=> 'featured_post_slider',
			'section' 			=> 'slider_effect_options',
			'default' 			=> $defaults['transition_effect'],
			'choices'			=> simplecatch_transition_effects(),
		),
		'transition_delay' => array(
			'id' 				=> 'transition_delay',
			'title' 			=> __( 'Transition Delay', 'simple-catch' ),
			'description'		=> '',
			'field_type' 		=> 'number',
			'sanitize' 			=> 'simplecatch_sanitize_number_range',
			'panel' 			=> 'featured_post_slider',
			'section' 			=> 'slider_effect_options',
			'default' 			=> $defaults['transition_delay'],
			'input_attrs' 		=> array(
						            'style' => 'width: 45px;',
						            'min'   => 0,
						            'max'   => 999999999,
						            'step'  => 1,
						        	)
		),
		'transition_duration' => array(
			'id' 				=> 'transition_duration',
			'title' 			=> __( 'Transition Length', 'simple-catch' ),
			'description'		=> '',
			'field_type' 		=> 'number',
			'sanitize' 			=> 'simplecatch_sanitize_number_range',
			'panel' 			=> 'featured_post_slider',
			'section' 			=> 'slider_effect_options',
			'default' 			=> $defaults['transition_duration'],
			'input_attrs' 		=> array(
						            'style' => 'width: 45px;',
						            'min'   => 0,
						            'max'   => 999999999,
						            'step'  => 1,
						        	)
		),

		//Footer Option
		'remove_footer_logo' => array(
			'id' 				=> 'remove_footer_logo',
			'title' 			=> __( 'Check to Disable Footer Logo', 'simple-catch' ),
			'description'		=> '',
			'field_type' 		=> 'checkbox',
			'sanitize' 			=> 'simplecatch_sanitize_checkbox',
			'panel' 			=> 'theme_options',
			'section' 			=> 'footer_options',
			'default' 			=> $defaults['remove_footer_logo'],
		),
		'featured_logo_footer' => array(
			'id' 				=> 'featured_logo_footer',
			'title' 			=> __( 'Footer Logo', 'simple-catch' ),
			'description'		=> '',
			'field_type' 		=> 'image',
			'sanitize' 			=> 'simplecatch_sanitize_image',
			'panel' 			=> 'theme_options',
			'section' 			=> 'footer_options',
			'default' 			=> $defaults['featured_logo_footer'],
		),
		'footer_code' => array(
			'id' 				=> 'footer_code',
			'title' 			=> __( 'Footer Editor', 'simple-catch' ),
			'description'		=> __( 'You can add custom HTML and/or shortcodes, which will be automatically inserted into your theme.
Some shorcodes: [footer-image], [the-year], [site-link], [wp-link] for current year, your site link, wordpress site link respectively.', 'simple-catch' ),
			'field_type' 		=> 'textarea',
			'sanitize' 			=> 'simplecatch_sanitize_footer_code',
			'panel' 			=> 'theme_options',
			'section' 			=> 'footer_options',
			'default' 			=> $defaults['footer_code'],
		),
		'reset_footer' => array(
			'id' 				=> 'reset_footer',
			'title' 			=> __( 'Check to Reset Footer', 'simple-catch' ),
			'description'		=> __( 'Please refresh the customizer after saving if reset option is used', 'simple-catch' ),
			'transport'			=> 'postMessage',
			'field_type' 		=> 'checkbox',
			'sanitize' 			=> 'simplecatch_sanitize_reset_footer',
			'panel' 			=> 'theme_options',
			'section' 			=> 'footer_options',
			'default' 			=> $defaults['reset_footer'],
		),

		//Update Notifier
		'disable_scrollup' => array(
			'id' 			=> 'disable_scrollup',
			'title' 		=> __( 'Check to Disable Scroll Up', 'simple-catch' ),
			'description' 	=> '',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'simplecatch_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'scrollup_options',
			'default' 		=> $defaults['disable_scrollup']
		),

		//Update Notifier
		'disable_notifier' => array(
			'id' 			=> 'disable_notifier',
			'title' 		=> __( 'Check to Disable Update Notifier', 'simple-catch' ),
			'description' 	=> '',
			'field_type' 	=> 'checkbox',
			'sanitize' 		=> 'simplecatch_sanitize_checkbox',
			'panel' 		=> 'theme_options',
			'section' 		=> 'update_notifier',
			'default' 		=> $defaults['disable_notifier']
		),


		//Social Links
		'social_facebook' => array(
			'id' 			=> 'social_facebook',
			'title' 		=> __( 'Facebook', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_facebook']
		),
		'social_twitter' => array(
			'id' 			=> 'social_twitter',
			'title' 		=> __( 'Twitter', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_twitter']
		),
		'social_googleplus' => array(
			'id' 			=> 'social_googleplus',
			'title' 		=> __( 'Google+', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_googleplus']
		),
		'social_pinterest' => array(
			'id' 			=> 'social_pinterest',
			'title' 		=> __( 'Pinterest', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_pinterest']
		),
		'social_youtube' => array(
			'id' 			=> 'social_youtube',
			'title' 		=> __( 'Youtube', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_youtube']
		),
		'social_vimeo' => array(
			'id' 			=> 'social_vimeo',
			'title' 		=> __( 'Vimeo', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_vimeo']
		),
		'social_linkedin' => array(
			'id' 			=> 'social_linkedin',
			'title' 		=> __( 'LinkedIn', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_linkedin']
		),
		'social_slideshare' => array(
			'id' 			=> 'social_slideshare',
			'title' 		=> __( 'Slideshare', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_slideshare']
		),
		'social_foursquare' => array(
			'id' 			=> 'social_foursquare',
			'title' 		=> __( 'Foursquare', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_foursquare']
		),
		'social_flickr' => array(
			'id' 			=> 'social_flickr',
			'title' 		=> __( 'Flickr', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_flickr']
		),
		'social_tumblr' => array(
			'id' 			=> 'social_tumblr',
			'title' 		=> __( 'Tumblr', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_tumblr']
		),
		'social_deviantart' => array(
			'id' 			=> 'social_deviantart',
			'title' 		=> __( 'deviantART', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_deviantart']
		),
		'social_dribbble' => array(
			'id' 			=> 'social_dribbble',
			'title' 		=> __( 'Dribbble', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_dribbble']
		),
		'social_myspace' => array(
			'id' 			=> 'social_myspace',
			'title' 		=> __( 'MySpace', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_myspace']
		),
		'social_wordpress' => array(
			'id' 			=> 'social_wordpress',
			'title' 		=> __( 'WordPress', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_wordpress']
		),
		'social_rss' => array(
			'id' 			=> 'social_rss',
			'title' 		=> __( 'RSS', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_rss']
		),
		'social_delicious' => array(
			'id' 			=> 'social_delicious',
			'title' 		=> __( 'Delicious', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_delicious']
		),
		'social_lastfm' => array(
			'id' 			=> 'social_lastfm',
			'title' 		=> __( 'Last.fm', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_lastfm']
		),
		'social_instagram' => array(
			'id' 			=> 'social_instagram',
			'title' 		=> __( 'Instagram', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_instagram']
		),
		'social_github' => array(
			'id' 			=> 'social_github',
			'title' 		=> __( 'GitHub', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_github']
		),
		'social_vkontakte' => array(
			'id' 			=> 'social_vkontakte',
			'title' 		=> __( 'Vkontakte', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_vkontakte']
		),
		'social_myworld' => array(
			'id' 			=> 'social_myworld',
			'title' 		=> __( 'My World', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_myworld']
		),
		'social_odnoklassniki' => array(
			'id' 			=> 'social_odnoklassniki',
			'title' 		=> __( 'Odnoklassniki', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_odnoklassniki']
		),
		'social_goodreads' => array(
			'id' 			=> 'social_goodreads',
			'title' 		=> __( 'Goodreads', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_goodreads']
		),
		'social_skype' => array(
			'id' 			=> 'social_skype',
			'title' 		=> __( 'Skype', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'sanitize_text_field',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_skype']
		),
		'social_soundcloud' => array(
			'id' 			=> 'social_soundcloud',
			'title' 		=> __( 'Soundcloud', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'esc_url_raw',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_soundcloud']
		),
		'social_email' => array(
			'id' 			=> 'social_email',
			'title' 		=> __( 'Email', 'simple-catch' ),
			'description'	=> '',
			'field_type' 	=> 'url',
			'sanitize' 		=> 'sanitize_email',
			'section' 		=> 'social_links',
			'default' 		=> $defaults['social_email']
		),

		//Webmaster Tools
		'analytic_header' => array(
			'id' 				=> 'analytic_header',
			'title' 			=> __( 'Code to display on Header', 'simple-catch' ),
			'description' 		=> __( 'Here you can put scripts from Google, Facebook, Twitter, Add This etc. which will load on Header', 'simple-catch' ),
			'field_type' 		=> 'textarea',
			'sanitize' 			=> 'wp_kses_stripslashes',
			'section' 			=> 'webmaster_tools',
			'active_callback'	=> 'simplecatch_is_header_code_present',
			'default' 			=> ''
		),
		'analytic_footer' => array(
			'id' 				=> 'analytic_footer',
			'title' 			=> __( 'Code to display on Footer', 'simple-catch' ),
			'description' 		=> __( 'Here you can put scripts from Google, Facebook, Twitter, Add This etc. which will load on footer', 'simple-catch' ),
			'field_type' 		=> 'textarea',
			'sanitize' 			=> 'wp_kses_stripslashes',
			'section' 			=> 'webmaster_tools',
			'active_callback'	=> 'simplecatch_is_footer_code_present',
			'default' 		=> ''
		),

		//Webmaster Setting
		'google_verification' => array(
			'id' 			=> 'google_verification',
			'title' 		=> __( 'Google Site Verification ID', 'simple-catch' ),
			'description'	=> __( 'Enter your Google ID number only', 'simple-catch' ),
			'field_type' 	=> 'text',
			'sanitize' 		=> 'wp_filter_post_kses',
			'panel' 		=> 'webmaster_tool',
			'section' 		=> 'site_verification',
			'default' 		=> $defaults['google_verification']
		),
		'yahoo_verification' => array(
			'id' 			=> 'yahoo_verification',
			'title' 		=> __( 'Yahoo Site Verification ID', 'simple-catch' ),
			'description'	=> __( 'Enter your Yahoo ID number only', 'simple-catch' ),
			'field_type' 	=> 'text',
			'sanitize' 		=> 'wp_filter_post_kses',
			'panel' 		=> 'webmaster_tool',
			'section' 		=> 'site_verification',
			'default' 		=> $defaults['yahoo_verification']
		),
		'bing_verification' => array(
			'id' 			=> 'bing_verification',
			'title' 		=> __( 'Bing Site Verification ID', 'simple-catch' ),
			'description'	=> __( 'Enter your Bing ID number only', 'simple-catch' ),
			'field_type' 	=> 'text',
			'sanitize' 		=> 'wp_filter_post_kses',
			'panel' 		=> 'webmaster_tool',
			'section' 		=> 'site_verification',
			'default' 		=> $defaults['bing_verification']
		),
		'analytic_header' => array(
			'id' 				=> 'analytic_header',
			'title' 			=> __( 'Code to display on Header', 'simple-catch' ),
			'description' 		=> __( 'Here you can put scripts from Google, Facebook etc. which will load on Header', 'simple-catch' ),
			'field_type' 		=> 'textarea',
			'sanitize' 			=> 'wp_kses_stripslashes',
			'panel' 			=> 'webmaster_tool',
			'section' 			=> 'header_footer_codes',
			'default' 			=> $defaults['analytic_header']
		),
		'analytic_footer' => array(
			'id' 				=> 'analytic_footer',
			'title' 			=> __( 'Code to display on Footer', 'simple-catch' ),
			'description' 		=> __( 'Here you can put scripts from Google, Facebook etc. which will load on Footer', 'simple-catch' ),
			'field_type' 		=> 'textarea',
			'sanitize' 			=> 'wp_kses_stripslashes',
			'panel' 			=> 'webmaster_tool',
			'section' 			=> 'header_footer_codes',
			'default' 			=> $defaults['analytic_footer']
		),
	);

	foreach ( $settings_parameters as $option ) {
		$priority 	= isset( $option['priority'] ) ? $option['priority'] : '' ;
		$transport 	= isset( $option['transport'] ) ? $option['transport'] : 'refresh' ;
		if( 'color' == $option['field_type'] ) {
			$wp_customize->add_setting(
				// $id
				$theme_slug . 'options[' . $option['id'] . ']',
				// parameters array
				array(
					'type'				=> 'option',
					'sanitize_callback'	=> $option['sanitize'],
					'default'			=> $option['default'],
					'transport'			=> $transport,
				)
			);

			$params = array(
						'label'			=> $option['title'],
						'settings'  	=> $theme_slug . 'options[' . $option['id'] . ']',
						'priority'		=> $priority,
					);

			if ( 'title_tagline' == $option['section'] || 'colors' == $option['section']){
				$params['section'] = $option['section'];
			}
			else {
				$params['section']	= $theme_slug . $option['section'];
			}

			if ( isset( $option['active_callback']  ) ){
				$params['active_callback'] = $option['active_callback'];
			}

			$wp_customize->add_control(
				new WP_Customize_Color_Control(
					$wp_customize,$theme_slug . 'options[' . $option['id'] . ']',
					$params
				)
			);
		}
		else if( 'image' == $option['field_type'] ) {
			$wp_customize->add_setting(
				// $id
				$theme_slug . 'options[' . $option['id'] . ']',
				// parameters array
				array(
					'type'				=> 'option',
					'sanitize_callback'	=> $option['sanitize'],
					'default'			=> $option['default'],
					'transport'			=> $transport,
				)
			);

			$params = array(
						'label'			=> $option['title'],
						'settings'  	=> $theme_slug . 'options[' . $option['id'] . ']',
						'priority'		=> $priority,
					);

			if ( 'title_tagline' == $option['section'] ){
				$params['section'] = $option['section'];
			}
			else {
				$params['section']	= $theme_slug . $option['section'];
			}

			if ( isset( $option['active_callback']  ) ){
				$params['active_callback'] = $option['active_callback'];
			}

			$wp_customize->add_control(
				new WP_Customize_Image_Control(
					$wp_customize,$theme_slug . 'options[' . $option['id'] . ']',
					$params
				)
			);
		}
		else if ('checkbox' == $option['field_type'] ) {
			$wp_customize->add_setting(
				// $id
				$theme_slug . 'options[' . $option['id'] . ']',
				// parameters array
				array(
					'type'				=> 'option',
					'sanitize_callback'	=> $option['sanitize'],
					'default'			=> $option['default'],
					'transport'			=> $transport,
					)
			);

			$params = array(
						'label'			=> $option['title'],
						'settings'  	=> $theme_slug . 'options[' . $option['id'] . ']',
						'name'  		=> $theme_slug . 'options[' . $option['id'] . ']',
						'priority'		=> $priority,
						'description'	=> $option['description'],
					);

			if ( isset( $option['active_callback']  ) ){
				$params['active_callback'] = $option['active_callback'];
			}

			if ( 'colors' == $option['section'] || 'title_tagline' == $option['section'] ){
				$params['section'] = $option['section'];
			}
			else {
				$params['section']	= $theme_slug . $option['section'];
			}

			$wp_customize->add_control(
				new Simple_Catch_Customize_Checkbox(
					$wp_customize,$theme_slug . 'options[' . $option['id'] . ']',
					$params
				)
			);
		}
		else if ('category-multiple' == $option['field_type'] ) {
			$wp_customize->add_setting(
				// $id
				$theme_slug . 'options[' . $option['id'] . ']',
				// parameters array
				array(
					'type'				=> 'option',
					'sanitize_callback'	=> $option['sanitize'],
					'default'			=> $option['default'],
					'transport'			=> $transport,
				)
			);

			$params = array(
						'label'			=> $option['title'],
						'section'		=> $theme_slug . $option['section'],
						'settings'		=> $theme_slug . 'options[' . $option['id'] . ']',
						'description'	=> $option['description'],
						'name'	 		=> $theme_slug . 'options[' . $option['id'] . ']',
						'priority'		=> $priority,
					);

			if ( isset( $option['active_callback']  ) ){
				$params['active_callback'] = $option['active_callback'];
			}

			$wp_customize->add_control(
				new Simple_Catch_Customize_Dropdown_Categories_Control (
					$wp_customize,
					$theme_slug . 'options[' . $option['id'] . ']',
					$params
				)
			);
		}
		//For Font Size
		else if( 'multiple-input' == $option['field_type'] ){
			/* Body Font Size */
			$option1_id = $option['id'];
			$option2_id = $option['id'].'_unit';

			$wp_customize->add_setting( $theme_slug .'options['. $option1_id .']', array(
		            'default'        	=> $defaults[$option1_id],
		            'capability'     	=> 'edit_theme_options',
		            'sanitize_callback'	=> $option['sanitize'],
		            'type'				=> 'option',
		        ) );

			$wp_customize->add_setting( $theme_slug .'options['. $option2_id .']', array(
		            'default'        	=> $defaults[$option2_id],
		            'capability'     	=> 'edit_theme_options',
		            'sanitize_callback'	=> $option['sanitize'],
		            'type'				=> 'option',
		        ) );

			$control = new Simplecatch_Customize_Multiple_Input_Control(
	            $wp_customize, $theme_slug .'options['. $option1_id .']', array(
	            'label'    		=> $option['title'],
	            'section'  		=> $theme_slug . $option['section'],
	            'settings'   	=> array (
	                $theme_slug .'options['. $option1_id .']',
	                $theme_slug .'options['. $option2_id .']',
	            )
	        ) );

		    $wp_customize->add_control( $control );
		}
		else {
			//Normal Loop
			$wp_customize->add_setting(
				// $id
				$theme_slug . 'options[' . $option['id'] . ']',
				// parameters array
				array(
					'default'			=> $option['default'],
					'type'				=> 'option',
					'sanitize_callback'	=> $option['sanitize'],
					'transport'			=> $transport,
				)
			);

			// Add setting control
			$params = array(
					'label'			=> $option['title'],
					'settings'		=> $theme_slug . 'options[' . $option['id'] . ']',
					'type'			=> $option['field_type'],
					'description'   => $option['description'],
					'priority'		=> $priority,
				) ;

			if ( isset( $option['choices']  ) ){
				$params['choices'] = $option['choices'];
			}

			if ( isset( $option['active_callback']  ) ){
				$params['active_callback'] = $option['active_callback'];
			}

			if ( isset( $option['input_attrs']  ) ){
				$params['input_attrs'] = $option['input_attrs'];
			}

			if ( 'colors' == $option['section'] ){
				$params['section'] = $option['section'];
			}
			else {
				$params['section']	= $theme_slug . $option['section'];
			}

			$wp_customize->add_control(
				// $id
				$theme_slug . 'options[' . $option['id'] . ']',
				$params
			);
		}
	}

	//Add featured post elements with respect to no of featured sliders
	for ( $i = 1; $i <= $options[ 'slider_qty' ]; $i++ ) {
		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[featured_slider][' . $i . ']',
			// parameters array
			array(
				'type'				=> 'option',
				'sanitize_callback'	=> 'simplecatch_sanitize_post_id'
			)
		);

		$wp_customize->add_control(
			$theme_slug . 'options[featured_slider][' . $i . ']',
			array(
				'label'		=> sprintf( __( '#%s Featured Post ID', 'simple-catch' ), $i ),
				'section'   => $theme_slug .'add_slider_options',
				'settings'  => $theme_slug . 'options[featured_slider][' . $i . ']',
				'type'		=> 'text',
					'input_attrs' => array(
	        		'style' => 'width: 100px;'
	    		),
				'active_callback'	=> 'simplecatch_is_post_slider_active',
			)
		);
	}

	//Add featured page elements with respect to no of featured slider
	for ( $i = 1; $i <= $options[ 'slider_qty' ]; $i++ ) {
		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[featured_slider_page][' . $i . ']',
			// parameters array
			array(
				'type'				=> 'option',
				'sanitize_callback'	=> 'simplecatch_sanitize_post_id'
			)
		);

		$wp_customize->add_control(
			$theme_slug . 'options[featured_slider_page][' . $i . ']',
			array(
				'label'				=> sprintf( __( 'Featured Page Slider #%s', 'simple-catch' ), $i ),
				'section'   		=> $theme_slug .'add_slider_options',
				'settings'  		=> $theme_slug . 'options[featured_slider_page][' . $i . ']',
				'type'	   			=> 'dropdown-pages',
				'active_callback' 	=> 'simplecatch_is_page_slider_active'
			)
		);
	}

	//Add featured image elements with respect to no of featured slider
	for ( $i = 1; $i <= $options[ 'slider_qty' ]; $i++ ) {
		$wp_customize->add_setting( $theme_slug . 'options[featured_slider_note]['. $i .']', array(
			'capability'		=> 'edit_theme_options',
			'sanitize_callback'	=> 'sanitize_text_field',
		) );

		$wp_customize->add_control( new Simplecatch_Note_Control(
			$wp_customize,
			$theme_slug . 'options[featured_slider_note]['. $i .']', array(
	        'active_callback'	=> 'simplecatch_is_image_slider_active',
	        'label'				=> __( 'Featured Slide #', 'simple-catch' ) . $i,
	        'section'  			=> $theme_slug .'add_slider_options',
	        'settings'			=> $theme_slug . 'options[featured_slider_note][' . $i . ']',
	        'type'     			=> 'description',
   		) ) );

		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[featured_image_slider_image][' . $i . ']',
			// parameters array
			array(
				'type'				=> 'option',
				'sanitize_callback'	=> 'simplecatch_sanitize_image'
			)
		);

		$wp_customize->add_control( new WP_Customize_Image_Control(
				$wp_customize,
				$theme_slug . 'options[featured_image_slider_image][' . $i . ']',
				array(
					'label'				=> __( 'Image', 'simple-catch' ),
					'section'   		=> $theme_slug .'add_slider_options',
					'settings'  		=> $theme_slug . 'options[featured_image_slider_image][' . $i . ']',
					'active_callback' 	=> 'simplecatch_is_image_slider_active'
				)
			)
		);

		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[featured_image_slider_link][' . $i . ']',
			// parameters array
			array(
				'type'				=> 'option',
				'sanitize_callback'	=> 'esc_url_raw'
			)
		);

		$wp_customize->add_control(
			$theme_slug . 'options[featured_image_slider_link][' . $i . ']',
			array(
				'label'				=> __( 'Link', 'simple-catch' ),
				'section'   		=> $theme_slug .'add_slider_options',
				'settings'  		=> $theme_slug . 'options[featured_image_slider_link][' . $i . ']',
				'type'	   			=> 'url',
				'active_callback' 	=> 'simplecatch_is_image_slider_active'
			)
		);

		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[featured_image_slider_base][' . $i . ']',
			// parameters array
			array(
				'type'				=> 'option',
				'sanitize_callback'	=> 'simplecatch_sanitize_checkbox'
			)
		);

		$wp_customize->add_control(
			$theme_slug . 'options[featured_image_slider_base][' . $i . ']',
			array(
				'label'				=> __( 'Check to Open Link in New Window/Tab ', 'simple-catch' ),
				'section'   		=> $theme_slug .'add_slider_options',
				'settings'  		=> $theme_slug . 'options[featured_image_slider_base][' . $i . ']',
				'type'	   			=> 'checkbox',
				'active_callback' 	=> 'simplecatch_is_image_slider_active'
			)
		);

		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[featured_image_slider_title][' . $i . ']',
			// parameters array
			array(
				'type'				=> 'option',
				'sanitize_callback'	=> 'sanitize_text_field'
			)
		);

		$wp_customize->add_control(
			$theme_slug . 'options[featured_image_slider_title][' . $i . ']',
			array(
				'label'				=> __( 'Title', 'simple-catch' ),
				'section'   		=> $theme_slug .'add_slider_options',
				'settings'  		=> $theme_slug . 'options[featured_image_slider_title][' . $i . ']',
				'type'	   			=> 'text',
				'active_callback' 	=> 'simplecatch_is_image_slider_active'
			)
		);

		$wp_customize->add_setting(
			// $id
			$theme_slug . 'options[featured_image_slider_content][' . $i . ']',
			// parameters array
			array(
				'type'				=> 'option',
				'sanitize_callback'	=> 'sanitize_text_field'
			)
		);

		$wp_customize->add_control(
			$theme_slug . 'options[featured_image_slider_content][' . $i . ']',
			array(
				'label'				=> __( 'Content', 'simple-catch' ),
				'section'   		=> $theme_slug .'add_slider_options',
				'settings'  		=> $theme_slug . 'options[featured_image_slider_content][' . $i . ']',
				'type'	   			=> 'textarea',
				'active_callback' 	=> 'simplecatch_is_image_slider_active'
			)
		);
	}


	// Reset all settings to default
	$wp_customize->add_section( 'simplecatch_reset_all_settings', array(
		'description'	=> __( 'Caution: Reset all settings to default. Refresh the page after save to view full effects.', 'simple-catch' ),
		'priority' 		=> 700,
		'title'    		=> __( 'Reset all settings', 'simple-catch' ),
	) );

	$wp_customize->add_setting( 'simplecatch_options[reset_all_settings]', array(
		'capability'		=> 'edit_theme_options',
		'sanitize_callback' => 'simplecatch_reset_all_settings',
		'transport'			=> 'postMessage',
	) );

	$wp_customize->add_control( 'simplecatch_options[reset_all_settings]', array(
		'label'    => __( 'Check to reset all settings to default', 'simple-catch' ),
		'section'  => 'simplecatch_reset_all_settings',
		'settings' => 'simplecatch_options[reset_all_settings]',
		'type'     => 'checkbox'
	) );
	// Reset all settings to default end

	//Important Links
	$wp_customize->add_section( 'important_links', array(
		'priority' 		=> 999,
		'title'   	 	=> __( 'Important Links', 'simple-catch' ),
	) );

	/**
	 * Has dummy Sanitizaition function as it contains no value to be sanitized
	 */
	$wp_customize->add_setting( 'important_links', array(
		'sanitize_callback'	=> 'simplecatch_sanitize_important_link',
	) );

	$wp_customize->add_control( new Simple_Catch_Important_Links( $wp_customize, 'important_links', array(
        'label'   	=> __( 'Important Links', 'simple-catch' ),
        'section'  	=> 'important_links',
        'settings' 	=> 'important_links',
        'type'     	=> 'important_links',
    ) ) );
    //Important Links End
}
add_action( 'customize_register', 'simplecatch_customize_register' );


/**
 * Binds JS handlers to make Theme Customizer preview reload changes asynchronously for simplecatch.
 * And flushes out all transient data on preview
 *
 * @since Simple Catch 1.6.3
 */
function simplecatch_customize_preview() {
	//Remove transients on preview
	simplecatch_themeoption_invalidate_caches();

	global $simplecatch_options_defaults ,$simplecatch_options_settings;

	$simplecatch_options_settings = simplecatch_options_set_defaults( $simplecatch_options_defaults );
}
add_action( 'customize_preview_init', 'simplecatch_customize_preview' );
add_action( 'customize_save', 'simplecatch_customize_preview' );


/**
 * Custom scripts and styles on Customizer for Simple Catch
 *
 * @since Simple Catch 1.4
 */
function simplecatch_customize_scripts() {
	wp_enqueue_script( 'simplecatch_customizer_custom', get_template_directory_uri() . '/functions/panel/customizer-custom-scripts.js', array( 'jquery' ), '20140108', true );
}
add_action( 'customize_controls_enqueue_scripts', 'simplecatch_customize_scripts' );


//Active callbacks for customizer
require get_template_directory() . '/functions/panel/customizer/customizer-active-callbacks.php';

//Sanitize functions for customizer
require get_template_directory() . '/functions/panel/customizer/customizer-sanitize-functions.php';
